use strict;
use warnings;
package oDZT;
# ABSTRACT: lots of false leads here
<<END
# VERSION
END

=pod

# VERSION

=cut

our $VERSION = ''; # VERSION

BEGIN { our $VERSION= 0; } # VERSION

our $FOO = 1; our $VERSION=0; our $BAR = 2; # VERSION

1;
__END__

# VERSION
