
BEGIN {
  unless ($ENV{AUTHOR_TESTING}) {
    print qq{1..0 # SKIP these tests are for testing by the author\n};
    exit
  }
}

use strict;
use warnings;
use Test::More;

# generated by Dist::Zilla::Plugin::Test::PodSpelling 2.007005
use Test::Spelling 0.12;
use Pod::Wordlist;


add_stopwords(<DATA>);
all_pod_files_spelling_ok( qw( bin lib ) );
__DATA__
Alceu
Alexandr
Alexei
Caleb
Christian
Christopher
Ciornii
Conrad
Cushing
David
Dist
FileFinder
Freitas
Golden
Graham
Grahan
Ian
Jemmeson
Junior
Loyd
Madsen
Michael
Ollis
OurPkgVersion
Plugin
Rodrigues
Sealy
Stephan
SubmittingPatches
Walde
Zilla
Znamensky
alceu
alexchorny
arfreitas
dagolden
de
dzil
executables
git
ini
lib
mike
mjemmeson
perl
perltidy
plicease
russoz
stephanloyd9
walde
xenoterracide
